@@ -10,6 +10,8 @@ from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityIIFValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityConstArrayValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSRankedSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSTopNSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSBottomNSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageAdjustedSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSZScoreSecurityValueHolder
@@ -24,6 +26,8 @@ __all__ = ['DataProvider',
            'SecurityIIFValueHolder',
            'SecurityConstArrayValueHolder',
            'CSRankedSecurityValueHolder',
+           'CSTopNSecurityValueHolder',
+           'CSBottomNSecurityValueHolder',
            'CSAverageSecurityValueHolder',
            'CSAverageAdjustedSecurityValueHolder',
            'CSZScoreSecurityValueHolder',
