@@ -38,11 +38,16 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityAcosValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAcoshValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAsinValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAsinhValueHolder
+from PyFin.Analysis.TechnicalAnalysis import SecurityNormInvValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityIIFValueHolder
 
 from PyFin.Analysis.CrossSectionValueHolders import CSRankedSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSTopNSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSBottomNSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSTopNPercentileSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSBottomNPercentileSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageAdjustedSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSZScoreSecurityValueHolder
@@ -54,6 +59,22 @@ def CSRank(x, groups=None):
     return CSRankedSecurityValueHolder(x, groups)
 
 
+def CSTopN(x, n, groups=None):
+    return CSTopNSecurityValueHolder(x, n, groups)
+
+
+def CSTopNQuantile(x, n, groups=None):
+    return CSTopNPercentileSecurityValueHolder(x, n, groups)
+
+
+def CSBottomN(x, n, groups=None):
+    return CSBottomNSecurityValueHolder(x, n, groups)
+
+
+def CSBottomNQuantile(x, n, groups=None):
+    return CSBottomNPercentileSecurityValueHolder(x, n, groups)
+
+
 def CSMean(x, groups=None):
     return CSAverageSecurityValueHolder(x, groups)
 
@@ -198,6 +219,10 @@ def ASINH(x):
     return SecurityAsinhValueHolder(x)
 
 
+def NORMINV(x):
+    return SecurityNormInvValueHolder(x)
+
+
 def SHIFT(x, n):
     return SecurityShiftedValueHolder(x, n)
 
@@ -206,10 +231,10 @@ def IIF(flag, left, right):
     return SecurityIIFValueHolder(flag, left, right)
 
 
-HIGH = functools.partial(LAST, 'high')
-LOW = functools.partial(LAST, 'low')
-OPEN = functools.partial(LAST, 'open')
-CLOSE = functools.partial(LAST, 'close')
+HIGH = functools.partial(LAST, 'highestPrice')
+LOW = functools.partial(LAST, 'lowestPrice')
+OPEN = functools.partial(LAST, 'openPrice')
+CLOSE = functools.partial(LAST, 'closePrice')
 
 
 
